@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.19 2002/04/30 14:54:37 paolo Exp $ */
+/* $Id: gdict-speller.c,v 1.9 2001/12/03 01:57:26 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -26,6 +26,7 @@
 #ifdef HAVE_GNOME_PRINT
 #  include <libgnomeprint/gnome-print.h>
 #  include <libgnomeprint/gnome-printer-dialog.h>
+#  include <libgnomeprint/gnome-printer-profile.h>
 #  include <math.h>
 #endif
 
@@ -41,8 +42,6 @@ enum {
     LAST_SIGNAL
 };
 
-GtkWidget *ss_label;
-
 static gint gdict_speller_signals[LAST_SIGNAL] = { 0, 0, 0 };
 
 static GnomeDialogClass *parent_class;
@@ -103,30 +102,6 @@ gdict_speller_get_type (void) {
     return gdict_speller_type;
 }
 
-
-static GtkWidget*
-gdict_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stock_id,
-			 gint response_id)
-{
-	GtkWidget *button;
-	
-	g_return_val_if_fail (GTK_IS_DIALOG (dialog), NULL);
-	g_return_val_if_fail (text != NULL, NULL);
-	g_return_val_if_fail (stock_id != NULL, NULL);
-
-	button = gdict_button_new_with_stock_image (text, stock_id);
-	g_return_val_if_fail (button != NULL, NULL);
-
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-
-	gtk_widget_show (button);
-
-	gtk_dialog_add_action_widget (dialog, button, response_id);	
-
-	return button;
-}
-
-
 /* gdict_speller_init
  *
  * Initialises an instance of a GDictSpeller object
@@ -135,9 +110,6 @@ gdict_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stoc
 static void 
 gdict_speller_init (GDictSpeller *speller) {
     GtkWidget *label, *button, *scrolled_win;
-    GtkWidget *hbox;
-    GtkWidget *vbox;
-    GtkWidget *frame;
     GtkListStore *model;
     GtkTreeViewColumn *column;
     GtkTreeSelection *selection;
@@ -148,67 +120,34 @@ gdict_speller_init (GDictSpeller *speller) {
     speller->spell_cmd = NULL;
     speller->strat = gdict_pref.dfl_strat;
     
-    vbox = gtk_vbox_new (FALSE, 8);
-    g_object_set (G_OBJECT (vbox), "border_width", 6, NULL);
+    speller->table = GTK_TABLE (gtk_table_new (2, 3, FALSE));
+    gtk_table_set_row_spacings (speller->table, 5);
+    gtk_table_set_col_spacings (speller->table, 5);
     
-    hbox = gtk_hbox_new (FALSE, 8);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-    
-    label = gtk_label_new_with_mnemonic (_("_Word:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    
-    speller->word_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (speller->word_entry));
-
-    gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (speller->word_entry), TRUE, TRUE, 0);
-    g_signal_connect (G_OBJECT (speller->word_entry), "activate",
-    	  	      G_CALLBACK (spell_entry_cb), speller);
-
-    if (gail_loaded)
-    {
-        add_atk_namedesc (label, _("Word"), _("Word"));
-        add_atk_namedesc (GTK_WIDGET(speller->word_entry), _("Word Entry"), _("Enter a word to know the spelling"));
-        add_atk_relation (GTK_WIDGET(speller->word_entry), label, ATK_RELATION_LABELLED_BY);
-    }
-  
-    if (gail_loaded)
-        add_atk_namedesc (GTK_WIDGET (button), NULL, _("Click to do the spell check"));
-    
-    speller->hbox = gtk_hbox_new (FALSE, 8);
-    gtk_box_pack_start (GTK_BOX (vbox), speller->hbox, FALSE, FALSE, 0);
-    
-    ss_label = gtk_label_new_with_mnemonic (_("Search S_trategy:"));
-    gtk_box_pack_start (GTK_BOX (speller->hbox), ss_label, FALSE, FALSE, 0);
-        
-    
-    hbox = gtk_hbutton_box_new ();
-    gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_END);
-		    
-    button = gdict_button_new_with_stock_image (_("Check _Spelling"), GTK_STOCK_SPELL_CHECK);
-    gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+    button = gtk_button_new_with_mnemonic (_("_Spell"));
+    gtk_table_attach_defaults (speller->table, button, 0, 1, 0, 1);
     g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (spell_button_pressed),
     		      speller);
-
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-
-    frame = gtk_frame_new (NULL);
     
-    label = gtk_label_new_with_mnemonic (_("Search _Results"));
-    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-    g_object_set (G_OBJECT (label), "xalign", 0.0, NULL);
-   
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-    gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
+    speller->word_entry = GTK_ENTRY (gtk_entry_new ());
+    gtk_table_attach_defaults (speller->table, 
+		               GTK_WIDGET (speller->word_entry), 1, 2, 0, 1);
+    g_signal_connect (G_OBJECT (speller->word_entry), "activate",
+    	  	      G_CALLBACK (spell_entry_cb), speller);
+    
+    label = gtk_label_new (_("Search Strategy:"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
+    gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+    gtk_table_attach_defaults (speller->table, label, 0, 1, 1, 2);
     
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
-    g_object_set (G_OBJECT (scrolled_win), "border_width", 6, NULL);
-
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
                                     GTK_POLICY_NEVER,
                                     GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_win),
-					 GTK_SHADOW_ETCHED_IN);
-    gtk_widget_set_size_request (scrolled_win, 400, 250);
+    gtk_widget_set_usize (scrolled_win, 400, 250);
+    
+    gtk_table_attach (speller->table, scrolled_win, 0, 2, 2, 3, 
+                      GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 5);
     
     model = gtk_list_store_new (1, G_TYPE_STRING);
     
@@ -216,8 +155,6 @@ gdict_speller_init (GDictSpeller *speller) {
     gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (speller->word_list), FALSE);
     g_object_unref (G_OBJECT (model));
     
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (speller->word_list));
-
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (speller->word_list));
     g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (row_selected_cb),
     		      speller);
@@ -229,28 +166,24 @@ gdict_speller_init (GDictSpeller *speller) {
     						       NULL);
     gtk_tree_view_column_set_sort_column_id (column, 0);
     
-    /*gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
-                                          0,GTK_SORT_ASCENDING); */
+    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
+                                          0,GTK_SORT_ASCENDING); 
                                           
     gtk_tree_view_append_column (GTK_TREE_VIEW (speller->word_list), column);
-
     gtk_container_add (GTK_CONTAINER (scrolled_win), speller->word_list);
-    gtk_container_add (GTK_CONTAINER (frame), scrolled_win);
-   
-    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (speller)->vbox), vbox);
-		    
-    gtk_dialog_add_button (GTK_DIALOG (speller), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
-    gdict_dialog_add_button (GTK_DIALOG (speller), _("_Look Up Word"), GTK_STOCK_FIND, 100);
-	   
-    gtk_dialog_set_default_response (GTK_DIALOG (speller), 100);
+
+    gtk_dialog_add_buttons (GTK_DIALOG (speller), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+    		                                  _("_Look Up"), 100,
+    		                                  NULL);
     g_signal_connect (G_OBJECT (speller->word_list), "row_activated",
-    		      G_CALLBACK (row_activated_cb), speller);
-    		      
+    		      G_CALLBACK (row_activated_cb), speller);	                                  
     g_signal_connect (G_OBJECT (speller), "response", G_CALLBACK (spell_response_cb),
     		      speller);
-    gtk_window_set_title (GTK_WINDOW (speller), _("Check Spelling"));
-                           
-    gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (speller)->vbox));
+    gtk_window_set_title (GTK_WINDOW (speller), _("Spell checker"));
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox),
+                        GTK_WIDGET (speller->table), 5, TRUE, TRUE);
+                         
+    gtk_widget_show_all (GTK_WIDGET (speller->table));
 }
 
 /* gdict_speller_class_init
@@ -456,7 +389,7 @@ gdict_speller_reset_strat (GDictSpeller *speller) {
     if (speller->strat_sel) {
         gtk_option_menu_remove_menu (speller->strat_sel);
         gtk_widget_destroy (GTK_WIDGET (speller->strat_sel));
-        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
+        gtk_widget_show_all (GTK_WIDGET (speller->table));
         speller->strat_sel = NULL;
     }
     
@@ -479,8 +412,8 @@ gdict_speller_reset_strat (GDictSpeller *speller) {
         alignment = gtk_alignment_new (0, 0.5, 0, 0);
         gtk_container_add (GTK_CONTAINER (alignment), 
                            GTK_WIDGET (error_label));
-        gtk_box_pack_start (GTK_BOX (speller->hbox), alignment, TRUE, TRUE, 0);
-        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
+        gtk_table_attach_defaults (speller->table, alignment, 1, 2, 1, 2);
+        gtk_widget_show_all (GTK_WIDGET (speller->table));
     }
 }
 
@@ -499,14 +432,9 @@ spell_error_cb (dict_command_t *command, DictStatusCode code,
     speller = GTK_WINDOW (data);
     
     if (code != DICT_SOCKET_ERROR) {
-        GtkWidget *dialog;
         string = g_strdup_printf (_("Error invoking query: %s"), message);
-        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-                                  	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  	 "%s", string, NULL); 
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-        g_free (string);
+        gnome_error_dialog_parented (string, speller);
+        
         if (command->cmd == C_MATCH)
           gtk_signal_emit (GTK_OBJECT (speller), 
                            gdict_speller_signals[WORD_LOOKUP_DONE_SIGNAL]);
@@ -543,19 +471,11 @@ speller_add_word (GDictSpeller *speller, gchar *word) {
 static void
 speller_set_strat_cb (GtkWidget *widget, gpointer data) {
     GDictSpeller *speller;
-    gchar *text;
     gchar *strat;
     
     speller = GDICT_SPELLER (data);
     strat = gtk_object_get_data (GTK_OBJECT (widget), "strat_name");
     speller->strat = strat;
-
-    text = gtk_editable_get_chars (GTK_EDITABLE (speller->word_entry), 0, -1);
-    gtk_editable_select_region (GTK_EDITABLE (speller->word_entry), 0,
-                                strlen (text));
-    gdict_speller_lookup (speller, text);
-    if (text)
-    	g_free (text);
 }
 
 /* speller_add_strat
@@ -566,17 +486,12 @@ speller_set_strat_cb (GtkWidget *widget, gpointer data) {
 static void
 speller_add_strat (GDictSpeller *speller, gchar *strat, gchar *desc) {
     GtkWidget *menu_item;
-    GtkWidget *label;
     
-    label = gtk_label_new (desc);
-    gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-    
-    menu_item = gtk_menu_item_new ();
+    menu_item = gtk_menu_item_new_with_label (desc);
     gtk_signal_connect (GTK_OBJECT (menu_item), "activate", 
                         GTK_SIGNAL_FUNC (speller_set_strat_cb), speller);
     gtk_object_set_data (GTK_OBJECT (menu_item), "strat_name", strat);
-    gtk_container_add (GTK_CONTAINER (menu_item), label);
-    gtk_widget_show_all (menu_item);
+    gtk_widget_show (menu_item);
     gtk_menu_append (speller->strat_list, menu_item);
     
     if (!strcmp (speller->strat, strat))
@@ -658,24 +573,15 @@ spell_strat_status_cb (dict_command_t *command, DictStatusCode code,
         alignment = gtk_alignment_new (0, 0.5, 0, 0);
         gtk_container_add (GTK_CONTAINER (alignment), 
                            GTK_WIDGET (speller->strat_sel));
-        gtk_box_pack_start (GTK_BOX (speller->hbox), alignment, TRUE, TRUE, 0);
-        gtk_widget_show_all (GTK_WIDGET (speller->hbox));
-
-        gtk_label_set_mnemonic_widget (GTK_LABEL (ss_label), GTK_WIDGET (speller->strat_sel));        
-
-        if ( gail_loaded )
-        {
-            add_atk_namedesc(ss_label, _("Search Strategy"), _("Search Strategy"));
-            add_atk_relation( GTK_WIDGET (speller->strat_sel), ss_label, ATK_RELATION_LABELLED_BY);
-        }
- 
+        gtk_table_attach_defaults (speller->table, alignment, 1, 2, 1, 2);
+        gtk_widget_show_all (GTK_WIDGET (speller->table));
     }
 }
 
 static void
 spell_response_cb (GtkDialog *dialog, gint id, gpointer data) {
 	GDictSpeller *speller;
-        
+	
 	g_return_if_fail (data);
 	speller = GDICT_SPELLER (data);
 	
